Contributing is pretty simple, just join our [Discord](https://discord.gg/udZSbhws9D) and shoot me a message. 

If you'd like to get started without that hassle, just pick out an issue and comment to assign it to yourself.
